package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.36.0 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.36.0) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`MP`!````"!\```````!``````````&@!`0``
M`````````$``.``(`$``%@`5``8````$````0`````````!``````````$``
M````````P`$```````#``0````````@``````````P````0``````@``````
M```"``````````(````````:`````````!H``````````0`````````!````
M!0```````````````````````````````````'R0````````?)``````````
M``$```````$````&````F/L```````"8^P$``````)C[`0``````Z`0`````
M``!`!0```````````0```````@````8```"H^P```````*C[`0``````J/L!
M``````#@`0```````.`!````````"`````````!0Y71D!````%"*````````
M4(H```````!0B@```````/P`````````_``````````$`````````%'E=&0&
M`````````````````````````````````````````````````````````!``
M````````4N5T9`0```"8^P```````)C[`0``````F/L!``````!H!```````
M`&@$`````````0`````````O;&EB+VQD+6UU<VPM86%R8V@V-"YS;RXQ````
M`````!$```!+````!`````@````A$!``!<`$@"@`$`6`AD"$@B$`!`D`!(F(
M@!A!N@0""$L```!,````4````%4```!6````70```%X```!?`````````&$`
M``!B`````````&,```!D````9P```````````````:\TZ&I_FGSJT^\.SMY'
M+6_%WQ\NQ9NVN(WQ#M1DU'QV5#R4(?_D#MEQ6!SZH6Q@PN4_++(!BV]"^M>'
MXD?&`5COEWF[XY)\5<,\TF>OS&:(!W#30T75[#-BV^T5C"7,?ZF<F^"G`@IJ
M&IY0O]I7&Z/@^TD``````````````````````````````````````P`'`'@9
M`````````````````````````P`2`````@`````````````````!````$@``
M```````````````````````)````$@`````````````````````````0````
M$0````````````````````````#=`0``$0````````````````````````!F
M`0``$@`````````````````````````7````$@``````````````````````
M``"V`0``$@`````````````````````````?````$@``````````````````
M```````F````$@````````````````````````#J`0``$@``````````````
M``````````#"`0``$@`````````````````````````O````(```````````
M``````````````#M`@``(0````````````````````````!'````$@``````
M``````````````````!-````$@````````````````````````!4````$@``
M``````````````````````"D`@``$@````````````````````````#"`@``
M$@````````````````````````!;````$@`````````````````````````%
M`@``$@````````````````````````!B````$@``````````````````````
M``"+`@``$@````````````````````````!I````$@``````````````````
M``````!Q````$@````````````````````````"=`@``$@``````````````
M``````````!Y````$@````````````````````````!T`@``$@``````````
M``````````````"!````$@````````````````````````"'````$@``````
M``````````````````"0````(`````````````````````````"T`@``$@``
M``````````````````````"L````$@````````````````````````"Q````
M$@````````````````````````"#`0``%@````````````````````````"2
M`@``$@`````````````````````````R`@``$@``````````````````````
M``"X````$@`````````````````````````D`@``$@``````````````````
M```````S`P``$@````````````````````````#L`@``$0``````````````
M``````````!6`@``$@````````````````````````#9`@``$@``````````
M``````````````#N`@``$0````````````````````````"_````$@``````
M``````````````````#(````$0````````````````````````!T`0``$@``
M``````````````````````#:````(@````````````````````````#I````
M(`````````````````````````#_````$@````````````````````````#1
M`@``$@````````````````````````!"`@``$@``````````````````````
M```$`0``(`````````````````````````!_`@``$@``````````````````
M```````>`0``$@````````````````````````"G`0``$@``````````````
M```````````C`0``$@````````````````````````!D`@``$@``````````
M``````````````"6`0``$@`````````````````````````I`0``$@``````
M```````````````````Z`0``$@```````````````````````````@``$@``
M``````````````````````""````$@`````````````````````````1`@``
M$@````````````````````````!+`@``$@````````````````````````"[
M`@``$@````````````````````````"L`@``$@``````````````````````
M``!``0``$@````````````````````````#[`0``$@``````````````````
M``````!'`0``$@````````````````````````!.`0``$@``````````````
M``````````#K`@``(0````````````````````````!?`0``$@``````````
M```````````````S!```$``3`-@``@````````````````#F`@``$@`)`&`=
M````````J`$```````#7`0``$@`*`&!)````````!`````````!U`P``$@`)
M`-0M````````-`4```````!#!```$@`)`.0T````````9`````````!2`P``
M$@`)`&PH````````!`````````#G`P``$@`'`'@9````````!`````````"8
M`P``$@`)``@S````````W`$```````#M`P``$``3`(```@``````````````
M```;!```$@`)`'`H````````Y`$```````#0`P``$``3`(```@``````````
M``````!C`P``$@`)`"`M````````M`````````""`P``$@`)`+PF````````
M+`````````"*`P``$@`)`,@L````````.`````````"N`P``$@`)`&A&````
M````9`$```````##`P``$@`)`%0J````````,`````````#<`P``$``3`-@`
M`@`````````````````^!```$``3`-@``@`````````````````8`P``$@`)
M`"0?````````*`````````#[`P``$@`)`(0J````````'`$```````"Y`P``
M$0`2`'@``@``````"``````````4!```$``2`(```@````````````````#5
M`P``$@`)``@?``````````````````#D`P``$@`)``Q&````````7```````
M```A`P``$@`)```M````````(``````````\`P``$@`)`#@G````````-`$`
M```````H!```$@`)`,Q'````````E`$````````R!```$``3`-@``@``````
M```````````'!```$@`)`*`K````````*`$`````````;W!E;F1I<@!M96UC
M;7``<W1D97)R`')E86QL;V,`86-C97-S`'-N<')I;G1F`%]?9&5R96=I<W1E
M<E]F<F%M95]I;F9O`&QS965K`&=E='!I9`!S=')C;7``;65M<V5T`'5N;&EN
M:P!M96UM;W9E`'-T<FYC;7``<W1R<F-H<@!L<W1A=`!C;&]S961I<@!?251-
M7V1E<F5G:7-T97)434-L;VYE5&%B;&4`;W!E;@!S=')S='(`<W1R8VAR`')E
M861L:6YK`%]?<W1A8VM?8VAK7V=U87)D`%]?8WAA7V9I;F%L:7IE`%]?<F5G
M:7-T97)?9G)A;65?:6YF;P!E>&ET`%])5$U?<F5G:7-T97)434-L;VYE5&%B
M;&4`<F5A9`!R;61I<@!?7V5R<FYO7VQO8V%T:6]N`&UK9&ER`&UE;6-P>0!S
M=')L96X`7U]S=&%C:U]C:&M?9F%I;`!G971U:60`4&5R;%]S>7-?=&5R;0!0
M97)L7W-Y<U]I;FET,P!03%]C=7)R96YT7V-O;G1E>'0`4&5R;%]A=&9O<FM?
M;&]C:P!P97)L7V-O;G-T<G5C=`!097)L7V=E=%]S=@!097)L7V-R;V%K7VYO
M8V]N=&5X=`!?9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!P
M97)L7V9R964`4&5R;%]M9U]S970`4&5R;%]A=&9O<FM?=6YL;V-K`%!E<FQ?
M<W9?<V5T<'8`4&5R;%]G=E]F971C:'!V`'!E<FQ?<G5N`%!E<FQ?;F5W6%,`
M<&5R;%]D97-T<G5C=`!B;V]T7T1Y;F%,;V%D97(`<&5R;%]P87)S90!097)L
M7W-A9F5S>7-M86QL;V,`<&5R;%]A;&QO8P!S=')C<'D`<F5A9&1I<@!S<')I
M;G1F`'-T<F1U<`!S=')T;VL`<'1H<F5A9%]A=&9O<FL`9G!R:6YT9@!?7VQI
M8F-?<W1A<G1?;6%I;@!?7U]E;G9I<F]N`&QI8G!E<FPN<V\`;&EB8RYM=7-L
M+6%A<F-H-C0N<V\N,0!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P
M=W5I9`!P87)?8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!P
M87)?<V5T=7!?;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?96YV
M7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!S:&%?=7!D871E`&UY7W!A
M<E]P;`!P87)?8F%S96YA;64`7U]B<W-?<W1A<G0`7U]E;F1?7P!S:&%?:6YI
M=`!?7V)S<U]S=&%R=%]?`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?961A
M=&$`<&%R7V9I;F1P<F]G`'-H85]F:6YA;`!?7V)S<U]E;F1?7P!?96YD`'!A
M<E]C;&5A;G5P`"]U<W(O;&EB+W!E<FPU+V-O<F5?<&5R;"]#3U)%`````)C[
M`0```````P0````````@(````````*#[`0```````P0```````#`'P``````
M`(#_`0```````P0```````!@'0```````)C_`0```````P0```````!@20``
M`````+#_`0```````P0```````!X&0```````````@```````P0`````````
M``(``````!@``@```````P0````````63````````"```@```````P0`````
M``!Q20```````#```@```````P0```````!22@```````#@``@```````P0`
M``````!+2@```````$```@```````P0````````*3````````$@``@``````
M`P0```````!H2@```````%```@```````P0````````23````````&```@``
M`````P0```````#\2P```````&@``@```````P0````````!3````````'@`
M`@```````P0````````;3````````(C_`0```````00```4`````````````
M`)#_`0```````00```8``````````````*#_`0```````00```X`````````
M`````*C_`0```````00``"```````````````+C_`0``````!@0``"0`````
M`````````,#_`0```````00``"T``````````````,C_`0```````00``"\`
M`````````````-#_`0```````00``#$``````````````-C_`0```````00`
M`#(``````````````.#_`0```````00``#8``````````````.C_`0``````
M`00``#L``````````````/#_`0```````00``#P``````````````/C_`0``
M`````00``$$``````````````*#]`0```````@0```,``````````````*C]
M`0```````@0```0``````````````+#]`0```````@0```<`````````````
M`+C]`0```````@0```@``````````````,#]`0```````@0```D`````````
M`````,C]`0```````@0```H``````````````-#]`0```````@0```L`````
M`````````-C]`0```````@0```P``````````````.#]`0```````@0```T`
M`````````````.C]`0```````@0```X``````````````/#]`0```````@0`
M`!```````````````/C]`0```````@0``!$```````````````#^`0``````
M`@0``!(```````````````C^`0```````@0``!,``````````````!#^`0``
M`````@0``!0``````````````!C^`0```````@0``!4``````````````"#^
M`0```````@0``!8``````````````"C^`0```````@0``!<`````````````
M`##^`0```````@0``!@``````````````#C^`0```````@0``!D`````````
M`````$#^`0```````@0``!H``````````````$C^`0```````@0``!L`````
M`````````%#^`0```````@0``!P``````````````%C^`0```````@0``!T`
M`````````````&#^`0```````@0``!X``````````````&C^`0```````@0`
M`!\``````````````'#^`0```````@0``"$``````````````'C^`0``````
M`@0``"(``````````````(#^`0```````@0``",``````````````(C^`0``
M`````@0``"4``````````````)#^`0```````@0``"8``````````````)C^
M`0```````@0``"<``````````````*#^`0```````@0``"@`````````````
M`*C^`0```````@0``"D``````````````+#^`0```````@0``"L`````````
M`````+C^`0```````@0``"P``````````````,#^`0```````@0``"X`````
M`````````,C^`0```````@0``#```````````````-#^`0```````@0``#$`
M`````````````-C^`0```````@0``#(``````````````.#^`0```````@0`
M`#,``````````````.C^`0```````@0``#0``````````````/#^`0``````
M`@0``#4``````````````/C^`0```````@0``#<```````````````#_`0``
M`````@0``#@```````````````C_`0```````@0``#D``````````````!#_
M`0```````@0``#H``````````````!C_`0```````@0``#T`````````````
M`"#_`0```````@0``#X``````````````"C_`0```````@0``#\`````````
M`````##_`0```````@0``$```````````````#C_`0```````@0``$(`````
M`````````$#_`0```````@0``$,``````````````$C_`0```````@0``$0`
M`````````````%#_`0```````@0``$4``````````````%C_`0```````@0`
M`$8``````````````&#_`0```````@0``$<``````````````&C_`0``````
M`@0``$@``````````````'#_`0```````@0``$H``````````````/U[OZG]
M`P"1_7O!J,`#7]8``````````/![OZGP``#0$<Y&^1!B-I$@`A_6'R`#U1\@
M`]4?(`/5\```T!'21OD0@C:1(`(?UO```-`1UD;Y$*(VD2`"'];P``#0$=I&
M^1#"-I$@`A_6\```T!'>1OD0XC:1(`(?UO```-`1XD;Y$`(WD2`"'];P``#0
M$>9&^1`B-Y$@`A_6\```T!'J1OD00C>1(`(?UO```-`1[D;Y$&(WD2`"'];P
M``#0$?)&^1""-Y$@`A_6\```T!'V1OD0HC>1(`(?UO```-`1^D;Y$,(WD2`"
M'];P``#0$?Y&^1#B-Y$@`A_6\```T!$"1_D0`CB1(`(?UO```-`1!D?Y$"(X
MD2`"'];P``#0$0I'^1!".)$@`A_6\```T!$.1_D08CB1(`(?UO```-`1$D?Y
M$((XD2`"'];P``#0$19'^1"B.)$@`A_6\```T!$:1_D0PCB1(`(?UO```-`1
M'D?Y$.(XD2`"'];P``#0$2)'^1`".9$@`A_6\```T!$F1_D0(CF1(`(?UO``
M`-`1*D?Y$$(YD2`"'];P``#0$2Y'^1!B.9$@`A_6\```T!$R1_D0@CF1(`(?
MUO```-`1-D?Y$*(YD2`"'];P``#0$3I'^1#".9$@`A_6\```T!$^1_D0XCF1
M(`(?UO```-`10D?Y$`(ZD2`"'];P``#0$49'^1`B.I$@`A_6\```T!%*1_D0
M0CJ1(`(?UO```-`13D?Y$&(ZD2`"'];P``#0$5)'^1"".I$@`A_6\```T!%6
M1_D0HCJ1(`(?UO```-`16D?Y$,(ZD2`"'];P``#0$5Y'^1#B.I$@`A_6\```
MT!%B1_D0`CN1(`(?UO```-`19D?Y$"([D2`"'];P``#0$6I'^1!".Y$@`A_6
M\```T!%N1_D08CN1(`(?UO```-`1<D?Y$(([D2`"'];P``#0$79'^1"B.Y$@
M`A_6\```T!%Z1_D0PCN1(`(?UO```-`1?D?Y$.([D2`"'];P``#0$8)'^1`"
M/)$@`A_6\```T!&&1_D0(CR1(`(?UO```-`1BD?Y$$(\D2`"'];P``#0$8Y'
M^1!B/)$@`A_6\```T!&21_D0@CR1(`(?UO```-`1ED?Y$*(\D2`"'];P``#0
M$9I'^1#"/)$@`A_6\```T!&>1_D0XCR1(`(?UO```-`1HD?Y$`(]D2`"'];P
M``#0$:9'^1`B/9$@`A_6\```T!&J1_D00CV1(`(?UO```-`1KD?Y$&(]D2`"
M'];P``#0$;)'^1""/9$@`A_6\```T!&V1_D0HCV1(`(?UO```-`1ND?Y$,(]
MD2`"'];]>[NI_0,`D?-3`:GS``#P]```T)3>1_GU$P#Y5=`[U>*'`ZGBXP"1
MX0,!D>!/`+G@,P&1F___E^(``-!"_$?YX```T`#X1_GA`P*J.?__E^```-``
MR$?Y``!`.4`!`#5P__^78N("D4`,`/E@``"U(`"`4I?__Y>J__^7H&IT^!_<
M*#FA:G3X("A2.0`$`#(@*!(YX$]`N10,`!$`$``1`'Q]DY?__Y?B(T#YXP,`
MJF#B`I'D3T"Y`P0`^4``0/E@``#Y````\`#8+Y%@!`#YX```\``\0/E@"`#Y
M````\`#D+Y%@#`#Y``"`T@$0`!$`!`"1(7Q]DY\``&L,!0!4=>("D7]H(?CB
M`Q0J!`"`T@$``+`AH!N1H`Y`^2G__Y?T`P`J@```-:`.0/EQ__^7]`,`*G7B
M`I&@#D#Y3?__EP```/``%"B1F@``E&`!`+6@"D#YH```M0```/``Z":1E```
ME*`*`/E@X@*1``A`^4```+2$!0"4<^("D6`.0/F0__^7N_[_E_430/G@`Q0J
M\U-!J?U[Q:C``U_617A@^&5H(?C2__\7'0"`TAX`@-+@`P"1X0``T"&@+I$?
M['R2`0``%.(#`*H%`(#2Y```T(3,1_E!A$#XXP``T&/81_G@``#0`,!'^2;_
M_Q<?(`/5X```\````I'A``#P(0`"D3\``.O```!4X0``T"'41_EA``"T\`,!
MJ@`"'];``U_6X```\````I'A``#P(0`"D2$``,LB_'_300R!BR'\09/!``"T
MX@``T$+P1_EB``"T\`,"J@`"'];``U_6'R`#U?U[OJG]`P"1\PL`^?,``/!@
M`D(Y``(`->```-``Z$?Y@```M.```/```$#Y"?__E]C__Y?@``#0`-!'^8``
M`+0@``#0`$`MD8[^_Y<@`(!28`(".?,+0/G]>\*HP`-?UN```+``[$?Y0`$`
MM/U[OZGA``#0(```T/T#`)$A(`*1`$`MD??^_Y?]>\&HS?__%\S__Q?]>[RI
M_0,`D?-3`:GU6P*I]V,#J0`%`+3V`P"JX```L`#@1_D7`$#Y=P0`M/@#`:KB
M`Q:J0`!`.1_T`'$$&$!Z(0,`5$(`%DOU`Q>J4WQ`D[0"0/G4`0"TX@,3JN$#
M%JK@`Q2JCO[_ER`"`#6`:G,X'_0`<<$!`%2U`A?+<P8`D90"$XNU_D.3%0,`
MN?5;0JG@`Q2J\U-!J?=C0ZG]>\2HP`-?UD($`)'C__\7M2(`D>C__Q<4`(#2
M]?__%^$``+`AY$?Y_7N^J?T#`)$B`$#YX@\`^0(`@-+A4P"1R?__E^$``+`A
MY$?YXP]`^2(`0/EC``+K`@"`TD```%3\_O^7_7O"J,`#7];]>[RI_0,`D?-3
M`:GS`P"J]-,`D>```+``Y$?Y]1,`^?4``+"UXD?Y`0!`^>$?`/D!`(#2X0,4
MJN`#$ZJO__^7(`$`M>```+``Y$?YXA]`^0$`0/E"``'K`0"`TD`!`%3A_O^7
MH`)`^>(W@+D"#`*+0`1`^4```/G@_?^T0B``D?S__Q?S4T&I]1-`^?U[Q*C`
M`U_6_7NUJ>$``+`AY$?Y_0,`D?,+`/GS`P"J(@!`^>)7`/D"`(#2X:,`D4;^
M_Y>``@`UX3M`N0(`E%(A#!02/Q!`<2000GK!``!4X`,3JD$`@%+P_?^7'P``
M<>`7GQKA``"P(>1'^>-70/DB`$#Y8P`"ZP(`@-*```!4MO[_EP``@%+W__\7
M\PM`^?U[RZC``U_6_7NSJ>$``+`AY$?Y_0,`D?-3`:GU6P*I]V,#J2(`0/GB
M9P#Y`@"`TF`"`+0!`$`Y]`,`J@$"`#2^_?^7]@,`JJ`!`+07``#0&```T/?&
M)9$8PR61X`,6JNK]_Y?S`P"JH`$`M>`#%JH6_O^7X`,4JFC^_Y?@``"P`.1'
M^>)G0/D!`$#Y0@`!ZP$`@-)@!0!4C/[_EW-.`)'A`Q>JX`,3JM3]_Y>`_?\T
MX0,8JN`#$ZK0_?^7`/W_-.`#%*I]_O^7]0,`JN`#$ZIZ_O^7M0(`"[4*`!&@
M?D"3WOW_E^,#$ZKB`Q2J]0,`J@$``-`AS"619/[_E^$C`9'@`Q6J5?[_EQ\$
M`#%``0!4X%M`N0`,%!(?$$!QP0``5.`#%:JY__^7X`,5JD?^_Y?+__\7X`,5
MJL3]_Y?[__\7\U-!J?5;0JGW8T.I_7O-J,`#7];_0P'1_T-`T>$``+`AY$?Y
MXD-`D?U[`*G]`P"1\U,!J?5;`JGU`P`J]@,!D?=C`ZD8`8#2]P``T",`0/E#
M)`#Y`P"`T@$`@-)"`(!2]R(`D3@`H/*,_?^7%`0`T>$#%.N`/D"2(3Q`D@%$
M@=J4`@'+=`#XM@``@)(9```4X0,4J@(`@%+@`Q4J?_W_E^(#&*KA`Q:JX`,5
M*@/^_Y<3?$"3?QX`\:D``%1S(@#1TP(3BW\"%NMB``!4E$)`T>W__Q?A`Q>J
MX`,3J@(!@-)*_?^7@`$`-6`"%LL``!2+X0``L"'D1_GC0T"19"1`^2(`0/F$
M``+K`@"`TH```%0>_O^7<P8`T>O__Q?]>T"I\U-!J?5;0JGW8T.I_T,!D?]#
M0)'``U_6_7NZJ?T#`)'S4P&I\P,!JO0#`*K@``"P`.1'^?5;`JGW8P.I^2,`
M^0$`0/GA+P#Y`0"`TF`"0#D?]`!Q00``5',&`)'@`Q.J_OW_E^%3`9'U`P"J
MX`,4JL/^_Y?V`P"J(`(`M/?]_Y>_`@#KJ`0`5`$`@-)@:F$XP&HA."$$`)&@
M__\UX```L`#D1_GB+T#Y`0!`^4(``>L!`(#2P`@`5.S]_Y?W``"P]^)'^0``
M@-+Y`D#Y(B,`T?8#`*H`!`"107A@^*'__[7A``#0P`H`$2*X0+D`?'V38@4`
M-.$#`*K@`QFJ`_W_E^`"`/G`_/^TX`)`^<$&`!'V5P"Y']@A^.`#%*H!`$`Y
M/_0`<2080'KA!`!4]P``L/?B1_D``!3+]E>`N;4*`)&@PB"+^`)`^=;R?=,K
M_?^7`&LV^$#Z_[3@`D#Y`&AV^.(#`*J!%D`X``0`D0'P'SAA```T/_0`<4'_
M_U2A!X!200``.0$`@-)B:F$X`F@A."$$`)&B__\UP?__%R(`@%(BN`"Y%?W_
ME_@#`*J`]_^TPGY]D^$#&:H4_?^7^`(`^=+__Q<`!`"1U?__%_-30:GU6T*I
M]V-#J?DC0/G]>\:HP`-?UN```+``W$?Y1-`[U>(``+!"]$?Y(P``T`$``-!C
M_"B1@&A@^"'D)9%__?\7_7N^J?T#`)'S4P&I4]`[U?0``+"4WD?Y8&IT^.[_
M_Y=@:G3X!```T/-30:F$U"^1_7O"J.,#!*H%`(!2`@``L`$``-!"(`R1(50F
MD;O\_Q<,"H32_V,LR^```+``Y$?Y_7L`J?T#`)'S4P&I].,`D?43`/D!`$#Y
MX2<0^0$`@-*^_/^7XP,`*@0``-`"``#0A*@FD4*X)I'@`Q2J(0""TJ+\_Y<?
M!``Q00$`5`,`@-+@``"P`.1'^>(G4/D!`$#Y0@`!ZP$`@-(`!0!48_W_EP!\
M0),?!$#Q20``5`!](-0`"(+2\V,@B^$#$ZK@`Q2J`@""T@7]_Y?T`P"J@/W_
M-P`$`!$`?$"3N/S_E^,#`*K@_/^TE7Y`DQ\`$^N"``!4```5BW\"`.NC_?]4
M?P`3ZXD``%1@`A6+?P``ZP/]_U0@`()2GP(`:ZS\_U3@`P.JX@,5JN$#$ZHT
M_?^7XP,`JA]H-3C3__\7_7M`J>`#`ZKS4T&I#`J$TO430/G_8RR+P`-?UK/_
M_Q<,'(+2_V,LR_U[`*G]`P"1\U,!J?0#`*KS`P&JX```L`#D1_GU6P*I]V,#
MJ?EK!*D!`$#YX6\(^0$`@-(```#0`.@FD1?^_Y?V`P"JX06`4N`#%*JW_/^7
MH`$`M````-#A`Q2J``PGD0;__Y?@``"P`.1'^>)O2/D!`$#Y0@`!ZP$`@-+@
M"0!4$OW_E^`#$ZJ4_/^7&```T!<``-`!0R>1&0``T/?\_Y?WQB61\P,`JCE+
M)Y'U8P.1,_W_M&`"0#D?``!Q<Q*7FK8``+3A`Q.JX`,6JDO\_Y>@!@`TX`,3
MJOC\_Y<!!`#180(!BW\"`>N"``!4(`!`.1^\`''``@!4X`,3JN_\_Y?Z`P"J
MX`,4JNS\_Y=:`P"+6@<`D5__/_'H^?]4Y0,4JN0#&:KC`Q.JX`,5J@(``-`!
M`(+20HPJD1C\_Y<`!``1'P1`<8D``%0`?2#4/_0?..7__Q?A8P&1X`,5JK_\
M_Y<@`@`UX&M`N0`,%!(?($!QH0$`5.`#%:HA`(!2`_S_ER`!`#7A`Q6J````
MT``,)Y&Z_O^7X`,5JE#\_Y?T`P"JL?__%P%#)Y$``(#2L_S_E_,#`*J___\7
M_7M`J>`#%*KS4T&I#!R"TO5;0JGW8T.I^6M$J?]C+(O``U_6_7N^J>$%@%+]
M`P"1\PL`^?,#`*HJ_/^70```M!,$`)'@`Q.J\PM`^?U[PJ@T_/\7#`:"TO]C
M+,OA``"P(>1'^?U[`*G]`P"1\U,!J2(`0/GB%PCY`@"`TH```+0!`$`Y]`,`
MJB$!`#7@``"P`.1'^>(72/D!`$#Y0@`!ZP$`@-)`!0!4FOS_EY7\_Y<`!`"1
M'P1`\8@%`%3A`Q2J\Z,`D>`#$ZH"_/^7X`,3JHS\_Y<`!`#18`(`BQ\`$^N)
M``!4`0!`.3^\`''``@!4X`,3JN$%@%+Z^_^7@/S_M!\`$^M)``!4'P``.>`#
M$ZH$_/^7X0``L"'D1_GC%TCY(@!`^6,``NL"`(#2X?O_5/U[0*D,!H+2\U-!
MJ?]C+(O``U_6'_0?..7__Q?]>T"I#`:"TO-30:D```#0_V,LBP#$)9'O^_\7
M``"`TNK__Q?]>[VI````T`!0)Y']`P"1\U,!J10``-`3``#0]5L"J6?]_Y<`
M``#0`'0GD63]_Y<```#0`)0GD6']_Y<6``#0````T`"X)Y%=_?^7<VXHD8#6
M)Y%:_?^7````T``4*)%7_?^7%0``T,#J)I%4_?^7H$8HD5+]_Y?@`Q.J4/W_
MEP```-``E"B13?W_EP```-``#">12OW_EP```-``O"B1-/W_EX```+3A`P"J
MX`,3JBC^_Y<```#0```ID2W]_Y?A`P"J@```M````-``2"F1(/[_EP```-``
M="F1)?W_E^$#`*I``0"TP.HFD1G^_Y?U6T*I@-8GD?-30:D!``#0_7O#J"'X
M*9$2_O\7````T`"T*9$7_?^7X0,`JJ#^_[2@1BB1\O__%_U[OZD```#0`$0H
MD?T#`)$._?^7X```M```0#F@```T'\``<>`'GQK]>\&HP`-?U@``@%+]__\7
M_7N_J?T#`)$2_/^7K?O_ET```+0``$#Y_7O!J,`#7];]>[VI_0,`D?5;`JD5
M``#0M@(JD?-3`:GS`P"JX`,6JO3\_Y>```"T`0!`.?0#`*KA```UX0,3JJ`"
M*I'S4T&I]5M"J?U[PZCB_?\7X0,3JH#[_Y>``@"UX`,3JNW[_Y?U`P"JX`,4
MJNK[_Y>@`@"+``@`D4_[_Y?D`Q2J]0,`JN(#$ZH#``#0`0``T&-`)Y$AC"J1
MT_O_E^$#%:K@`Q:JY___%_-30:GU6T*I_7O#J,`#7];]>ZBI_0,`D?-3`:GT
M`P"JX```L`#D1_GU6P*I]H,!D?=C`ZGWXP&1%0``T/EK!*GY0P*1^RL`^0$`
M0/GAOP#Y`0"`TN```-``(`"1`1!`^<$*`/D!H`"1`@Q!J>(/!JD@!$"M`HQ%
MJ>*/!ZD@!P"M(`C`/0`T0/G@"@#YH.HFD2`+@#VN_/^7H`(`M`$`0#GS`P"J
M00(`-*W__Y?@``"P`.1'^>*_0/D!`$#Y0@`!ZP$`@-)```!4K?O_E_5;0JG@
M`Q.J\U-!J?=C0ZGY:T2I^RM`^?U[V*@I^_\7E/__E_,#`*K@`0"UX`)`^8``
M`+43``#0<T(JD0H``!20_/^78```M?<B`)'X__\7`0!`.:'__S0:^_^7\P,`
MJD#__[3@`Q.JCOO_EP#X?],:``#0``0`D5I?*I'Q^O^7^`,`JO<#`*IB`D`Y
MH@<`-3,#0/DS"`"ULP``M=<"0/E7"@"TX`)`.4`)`#7@`Q.J?/O_E_<#`*K@
M`QBJ>?O_E_<"``OW$A`1&0``T/=^0)/@`Q>JV_K_E^4#&*HC2R>1X@,3J@0`
M`-"$<"J1]@,`J@$``-`AA"J17OO_E^`#%JH!.(!21_O_EQ\$`#$A!P!40/O_
MEP0`0+F?1`!QH`8`5.```+``Q$?Y`0``T(("0/GC`Q:J``!`^2&H*I$=^_^7
M$P"`TN```+``Y$?YXK]`^0$`0/E"``'K`0"`T@'U_U3U6T*IX`,3JO-30:GW
M8T.I^6M$J?LK0/G]>]BHP`-?UN`#%ZKA`QJJ<P8`D?<*`)$X^_^7O?__%^`#
M$ZHY_/^7\P,`JB`!`+0!`$`YX0``-&S\_Y>@```TX`,3JL'Z_Y?S`P"JM?__
M%SDC`)&Q__\7X`,7JM8B`)%B_/^7`/;_-.`#%ZKV__\7$P"`TK#__Q?A`P.1
MX`,6JJKZ_Y?Z`P`JH```->#30+D`#!02'Q!`<4`!`%3@``"0`,1'^>,#%JJ"
M`D#Y`0``L```0/DAE"N1X/K_E\/__Q?SVT"Y(?O_EW\"`&N!_O]4X--`N0`@
M`!(?``=Q`?[_5.`#%ZIY^O^7\P,`J@```+``+"J1!?S_E^$#`*K`"@"UEP)`
M^>`#%ZH(^_^7^`,`JA\,`'%M`P!4`'Q`DP$``+``$`#1(>`LD>`"`(M/^O^7
M@`(`-1\3`'&@``!4&!<`4>#*>#@?O`!QP0$`5)0&0/F4`0"TX`,4JO3Z_Y<?
M#`#Q"0$`5``0`-$!``"P@`(`BR'T+)$]^O^7'P``<?<2E)H8``"PS_[_EP`'
M`#7@`Q>J`0"`4G'Z_Y?T`P`J8`8`-(G\_Y?W`P"J``;XMP$H`-'[`P61`@"`
M4N`#%"HC^O^7X0,;JL(`@-+@`Q0JI_K_ER$``+`A_"B1(2@`D>`#&ZK"`(#2
M]?G_EP`$`#7AR@#1`@"`4O<C!9'@`Q0J$_K_E^$#%ZH"!8#2X`,4*I?Z_Y<!
M``"P!=<OD>0#%ZHC2R>1X@,6JB$(+9'@`Q.J_\,%.;+Z_Y?@`Q:JH/K_E^$#
M$ZJ@ZB:1J?S_E^`#$ZJS_O^77___%X`"0/F$_?^7]P,`JB#U_[6G__\7`0``
ML````+`A^"F1`$0HD10``+"4?BV1FOS_EQC7+Y'T^?^7.4LGD>0#`"KE`QBJ
MXP,9JN(#%JK@`Q.J`0``L"%$+9&3^O^7X`,3J@$X@%)\^O^7'P0`,:'[_U1U
M^O^7``!`N1]$`'$A^_]4X?G_EUH'`!'D`P`JY@,8JN4#&BKC`QFJX@,6JN$#
M%*K@`Q.J@/K_E^W__Q?]>[RI_0,`D?-3`:E4T#O5\P``D'/>1_GU6P*I]QL`
M^8!J<_@!P$(Y`<0".0```+``U">1=?O_E\```+0!`$`Y/\0`<6$``%0`!$`Y
M0```-!+^_Y>`:G/X8P"`4B(`@%(!``"P(<`MD0CZ_Y?U`P"JH`$`M``(0/D"
M``"P0L@MD0$`0/F`:G/X"/K_EZ`*0/D!`$#Y(`Q`N6``L#:`:G/XPOG_EX!J
M<_AC`(!2(@"`4@$``+#U``"P(=PMD?/Y_Y?W`P"JH`(`M````+``#">13OO_
ME^(#`*K```"TX`I`^0$`0/F`:G/X\/G_EPL``!30_/^7]@,`JN`*0/DV!`"T
M`0!`^>(#%JJ`:G/XY_G_E^`#%JHI^O^7EFIS^"(`@%(!``"P(>0MD>`#%JIO
M^?^7`@``L.$#`*I"."Z1X`,6JMKY_Y>`:G/XL^("D1_$`CD```"P`.@FD2S[
M_Y=@"@#Y@`$`M6`&0/E9_O^78`H`^0`!`+4```"P`%`ND6OY_Y>AX@*1(01`
M^2(`0/G5__\7M>("D0$X@%*@"D#Y`_K_E^,#`"H`!``1'P0`<62(47K```!4
MH(I`J0$`0/D```"P`-0ND5GY_Y?S4T&I]5M"J?<;0/G]>\2HP`-?UOU[OJG]
M`P"1\U,!J?,#`*ID_?^75_W_E_0#`*KR_?^7P`$`-+,!`+1@`D`Y8`$`-`$`
M`+#@`Q2J(7`JD93Y_Y>?`@#KH0``5.`#$ZKS4T&I_7O"J%+[_Q?S4T&I_7O"
MJ,`#7];_@PK1!>``D>$``)`AY$?Y!^`!D?U[`*G]`P"1(@!`^>)/`?D"`(#2
MXF,`D>8#`JJA`$"YQD``D:2$0/@A",!:P0`?^('\8-,C'`A3(=QXTR$<<))A
M``&J@_QHTV,<>))DX$2J(0`$JL&`'_C_``7K`?[_5`,(@%)$`$#Y8P0`<4$(
M0/E"(`"111Q`^2$`!,I$,$#YA``%RB$`!,HD_%_3@00!JB%\0))!/`#Y8?[_
M5`0<0*DI,X_2!1A!J4E0J_(($$#Y@?Q;T^/\0M,A%`2J8W@'JL(`!<IM?$"2
M0@`'BJH!!<I"``;*2@$$BD%`(8M*`07*X@]`^4H!!HOK%T#Y0@`)BR$``HOB
M$T#Y(0`("VL!"8M"``F+2@$"BR+\6]-"%`&J2@$""X+\0M-">`2J8P`"RDQ\
M0))C``&*8P`-RF,`!8MC``N+2_U;TVL5"JIC``L+*_Q"TV%Y`:I"``'**WQ`
MDD(`"HI"``S*0@`-B^T;0/FM`0F+0@`-BVW\6].M%0.J0@`-"TW]0M.J>0JJ
M(0`*RDU]0)(A``.*(0`+RB$`#(OL'T#YC`$)BR$`#(M,_%O3C!4"JB$`#`ML
M_$+3@WD#JDH!`\IL?$"22@$"BDH!#<I*`0N+ZR-`^6L!"8M*`0N+*_Q;TVL5
M`:I*`0L+2_Q"TV)Y`JIC``+*2WQ`DF,``8IC``S*8P`-B^TG0/FM`0F+8P`-
MBTW]6].M%0JJ8P`-"RW\0M.A>0&J0@`!RBY\0))"``J*0@`+RD(`#(OL*T#Y
MC`$)BT(`#(ML_%O3C!4#JD(`#`M,_4+3BGD*JB$`"LI-?4"2(0`#BB$`#LHA
M``N+ZR]`^6L!"8LA``N+2_Q;TVL5`JHA``L+:_Q"TV-Y`ZI+`0/*;'Q`DNHS
M0/EK`0**:P$-RDH!"8MK`0Z+:P$*BRK\6]-*%0&J:P$*"TK\0M-">0*J8P`"
MRDI\0))C``&*8P`,RF,`#8OM-T#YK0$)BV,`#8MM_5O3K14+JF,`#0LM_$+3
MH7D!JD(``<HM?$"20@`+BD(`"LI"``R+[#M`^8P!"8M"``R+;/Q;TXP5`ZI"
M``P+;/U"TXMY"ZHA``O*;'U`DB$``XHA``W*(0`*B^H_0/E*`0F+(0`*BTK\
M6]-*%0*J(0`*"VK\0M-*>0.J8P$*RDY]0)+K0T#Y8P`"BF,`#,IK`0F+8P`-
MBV,`"XLK_%O3:Q4!JF,`"PM+_$+3:WD"JD(!"\IM?4"2ZD=`^4(``8I"``[*
M2@$)BT(`#(M"``J+:OQ;TTH5`ZI"``H+*OQ"TTIY`:IA`0K*3'U`DNM+0/DA
M``.*(0`-RFL!"8LA``Z+(0`+BTO\6]-K%0*J(0`+"VO\0M-C>0.J2@$#RFM\
M0))*`0**2@$,RDH!#8OM3T#YK0$)BTH!#8LM_%O3K14!JDH!#0M-_$+3HGD"
MJF,``LI-?$"28P`!BF,`"\IC``R+[%-`^8P!"8MC``R+3/U;TXP5"JIC``P+
M+/Q"TX%Y`:I"``'*;_Q;TT(`"HKO%0.J0@`-RBQ\0))"``N+ZU=`^6L!"8M"
M``N+4$`OB^\!`@M"_4+32G@*JN[]6]/B6T#Y(0`*RB$``XK.%0^J(0`,RD(`
M"8LA``V+;?Q"TZUY`ZHA``*+XE]`^4L!#<HQ0"Z+:P$02LX!`0LA=)W2(=NM
M\FL!#(M"``&+Z?U"TREY#ZIK`0*+POU;TZ,!"<I"%`ZJ8P`12G!!(HM"``L+
M:T`JB^-C0/E,_%O3C!4"JF,``8MK`0.+P_U"TV]!+(MC>`ZJC`$+"RH!`\KK
M9T#Y2@$02DI!+8MK`0&+2@$+BXO]6]-K%0RJ3D$KBVL!"@M*_$+30GD"JFH`
M`LI*`0]*24$IB^IK0/E*`0&+*0$*BVK]6]-*%0NJ+4$JBTH!"0N)_4+3+'D,
MJDD`#,HI`0Y*(T$CB^EO0/DI`0&+8P`)BTG]6],I%0JJ;D`IBRD!`PMC_4+3
M:W@+JH,!"\IC``U*8D`BB^-S0/EC``&+0@`#BR/]6]-C%`FJ34`CBV,``@M"
M_4+32G@*JF(!"LI"``Y*3$`LB^)W0/E"``&+C`$"BV+\6]-"%`.JCD$BBT(`
M#`LL_4+3B7D)JDP!"<J,`0U*BT$KB^Q[0/F,`0&+:P$,BTS\6].,%0*J;4$L
MBXP!"PMK_$+38WD#JBL!`\IK`0Y*:D$JB^M_0/EK`0&+2@$+BXO]6]-K%0RJ
M3D$KBVL!"@M*_$+30GD"JFH``LI*`0U*24$IB^J#0/E*`0&+*0$*BVK]6]-*
M%0NJ+4$JBTH!"0N)_4+3+'D,JDD`#,HI`0Y*(T$CB^F'0/DI`0&+8P`)BTG]
M6],I%0JJ;D`IBRD!`PMC_4+3:W@+JH,!"\IC``U*8D`BB^.+0/EC``&+0@`#
MBR/]6]-C%`FJ34`CBV,``@M"_4+32G@*JF(!"LI"``Y*3$`LB^*/0/E"``&+
MC`$"BV+\6]-"%`.JCD$BBT(`#`LL_4+3B7D)JDP!"<J,`0U*BT$KB^R30/F,
M`0&+:P$,BTS\6].,%0*J;4$LBXP!"PMK_$+38WD#JBL!`\IK`0Y*:D$JB^N7
M0/EK`0&+2@$+BXO]6]-K%0RJ3T$KBVL!"@M*_$+30GD"JFH``LI*`0U*24$I
MB^J;0/E*`0&+*0$*BVK]6]-*%0NJ30$)"RY!*HN)_4+3+'D,JJK]6]-)``S*
M2A4-JBD!#THC02.+Z9]`^2D!`8MC``F+;T`JBTH!`PMC_4+3:W@+JDG]6].#
M`0O**14*JF,`#DIB0"*+XZ-`^6,``8M"``.+3D`IBRD!`@NB_4+337@-JF(!
M#<I"``]*0T`LB^*G0/GLKT#Y0@`!BV,``HLB_5O30A0)JF,``@M"_4+32G@*
MJJ(!"LI"``Y*0D`KB^NK0/EA`0&+0@`!BV'\6],A%`.J0@`!"R']0M,I>`FJ
M2P$)JB$!"@IK`0.*:P$!JF%!+8N+FY?2:^.Q\HP!"XLA``R+3/Q;TXP5`JHA
M``P+;/Q"TX-Y`ZHL`0.J;0`)"HP!`HJ,`0VJBD$JB^RS0/F,`0N+2@$,BRS\
M6].,%0&J2@$,"TS\0M.">0*J;``"JDT``PJ,`0&*C`$-JHE!*8OLMT#YC`$+
MBRD!#(M,_5O3C!4*JBD!#`LL_$+3@7D!JDP``:HM``(*C`$*BHP!#:J#02.+
M[+M`^8P!"XMC``R++/U;TXP5":IC``P+3/U"TXIY"JHL``JJ30$!"HP!"8J,
M`0VJ@D$BB^R_0/F,`0N+0@`,BVS\6].,%0.J0@`,"RS]0M.)>0FJ3`$)JBT!
M"@J,`0.*C`$-JH%!(8OLPT#YC`$+BR$`#(M,_%O3C!4"JB$`#`ML_$+3@WD#
MJBP!`ZIM``D*C`$"BHP!#:J*02J+[,=`^8P!"XM*`0R++/Q;TXP5`:I*`0P+
M3/Q"TX)Y`JIL``*J30`#"HP!`8J,`0VJB4$IB^S+0/F,`0N+*0$,BTS]6].,
M%0JJ*0$,"RS\0M.!>0&J3``!JBT``@J,`0J*C`$-JH-!(XOLST#YC`$+BV,`
M#(LL_5O3C!4)JF,`#`M,_4+3BGD*JBP`"JI-`0$*C`$)BHP!#:J"02*+[--`
M^8P!"XM"``R+;/Q;TXP5`ZI"``P++/U"TXEY":I,`0FJ+0$*"HP!`XJ,`0VJ
M@4$AB^S70/F,`0N+(0`,BTS\6].,%0*J(0`,"VS\0M.#>0.J+`$#JFT`"0J,
M`0**C`$-JHI!*HOLVT#YC`$+BTH!#(LL_%O3C!4!JDH!#`M,_$+3@GD"JFP`
M`JI-``,*C`$!BHP!#:J)02F+[-]`^8P!"XLI`0R+3/U;TXP5"JHI`0P++/Q"
MTX%Y`:I,``&J+0`""HP!"HJ,`0VJ@T$CB^SC0/F,`0N+8P`,BRS]6].,%0FJ
M8P`,"TS]0M.*>0JJ+``*JDT!`0J,`0F*C`$-JH)!(HOLYT#YC`$+BT(`#(ML
M_%O3C!4#JD(`#`LL_4+3B7D)JDP!":HM`0H*C`$#BHP!#:J!02&+[.M`^8P!
M"XLA``R+3/Q;TXP5`JHA``P+;/Q"TX-Y`ZHL`0.J;0`)"HP!`HJ,`0VJBD$J
MB^SO0/F,`0N+2@$,BRS\6].,%0&J2@$,"TS\0M.">0*J;``"JDT``PJ,`0&*
MC`$-JHE!*8OL\T#YC`$+BRD!#(M,_5O3C!4*JBD!#`LL_$+3C7D!JDP`#:JA
M`0(*C`$*BHP!`:KA]T#Y@T$CBRS]6],A``N+C!4)JF,``8M!_4+3*G@*JH\!
M`PMP0"R+HP$*JD$!#0IC``F*8P`!JN'[0/EB0"*+X_U;TV,4#ZHA``N+0@`!
MBR']0M-N``(+*W@)JE%`(XM!`0O*XO]`^2$`$$K,_5O3PSJ8TD-,N?*,%0ZJ
M0@`#BR%`+8LA``*+B0$!"S!`+(OA_4+3(G@/JBS]6]-A`0+*C!4)JB$`$4HA
M0"J+Z@-!^4H!`XLA``J+ROU"TTIY#JHM0"R+@0$!"TP`"LJ,`1!*BT$KB^P'
M0?F,`0.+:P$,BRS\6].,%0&J;D$LBXP!"PLK_4+3:7D)JDL!"<IK`0U*8D$B
MB^L+0?EK`0.+0@`+BXO]6]-K%0RJ34`KBVL!`@LB_$+307@!JB(!`<I"``Y*
M2D`JB^(/0?E"``.+2@$"BV+]6]-"%`NJ3D$BBT(`"@N*_4+33'D,JBH`#,I*
M`0U*24$IB^H30?E*`0.+*0$*BTK\6]-*%0*J+4$JBTH!"0MI_4+3*WD+JHD!
M"\HI`0Y*(4$AB^D70?DI`0.+(0`)BTG]6],I%0JJ+D`IBRD!`0M!_$+3(G@"
MJF$!`LHA``U*+$`LB^$;0?DA``.+C`$!BR']6],A%`FJC4$ABR$`#`M,_4+3
MBGD*JDP`"LJ,`0Y*BT$KB^P?0?F,`0.+:P$,BRS\6].,%0&J;D$LBXP!"PLK
M_4+3:7D)JDL!"<IK`0U*8D$BB^LC0?EK`0.+0@`+BXO]6]-K%0RJ34`KBVL!
M`@LB_$+307@!JB(!`<I"``Y*2D`JB^(G0?E"``.+2@$"BV+]6]-"%`NJ3D$B
MBT(`"@N*_4+33'D,JBH`#,I*`0U*24$IB^HK0?E*`0.+*0$*BTK\6]-*%0*J
M+4$JBTH!"0MI_4+3*WD+JHD!"\HI`0Y*(4$AB^DO0?DI`0.+(0`)BTG]6],I
M%0JJ+D`IBRD!`0M!_$+3(G@"JF$!`LHA``U*+$`LB^$S0?DA``.+C`$!BR']
M6],A%`FJC4$ABR$`#`M,_4+3BGD*JDP`"LJ,`0Y*BT$KB^PW0?F,`0.+:P$,
MBRS\6].,%0&J;D$LBXP!"PLK_4+3:7D)JDL!"<IK`0U*8D$BB^L[0?EK`0.+
M0@`+BXO]6]-K%0RJ34`KBVL!`@LB_$+307@!JB(!`<I"``Y*2D`JB^(_0?E"
M``.+2@$"BV+]6]-"%`NJ3T$BBT(`"@N*_4+33'D,JBH`#,I*`0U*A$`LBTE!
M*8OJ0T'Y2@$#BRD!"HM*_%O32A4"JDT!"0LN02J+:?U"TRMY"ZJ)`0O**0$/
M2B%!(8OI1T'Y*0$#BR$`"8NI_5O3*14-JB$`"0M)_$+3(GD"JFH!`LHI_%O3
M*14!JDH!#DHI`0J+(0`'"^I+0?E"``8+`@P`^4,!`XMC``2+(P$#"P,$`*FA
M_4+3(7@-JB$`!0L!"`#Y80$("P$0`/G```#P`.1'^>)/0?D!`$#Y0@`!ZP$`
M@-)```!4T?7_E_U[0*G_@PJ1P`-?UOU[OZD`$(#2_0,`D2[U_Y<?_`*I(F"$
MTJ+HK/("``#Y(G&5TA]X`+FB^;WR`@0`^<*?F])"%[/R`@@`^<*.BM)"!J+R
M`@P`^0(^G-)">KCR`A``^?U[P:C``U_6_7N\J?T#`)'S4P&I]`,`JO,#`:KU
M6P*I0'Q`D_4#`*KW8P.I@19`^2(,``L_``+KB0``5($:0/DA!`"1@1H`^8$:
M0/F6X@"1('1`BX*"`JF`>D"YH`,`-!<(@%+W`@!+_P(5:\#"((OWTI4:^'Y`
MDQ\`$^NB``!4`0`8BW\"`>O"``!4`'T@U&$"&(MI``!4'P`!Z_O__Q?B`QBJ
MX0,3JH+U_Y>`>D"YX`(`"X!Z`+D?``%Q00(`5+4"%TMS`AB+X`,4JH?[_Y>7
MX@&1O_X`<0P"`%2B?D"3?P(6Z\D#`%3``@*+?P(`Z^/\_U3A`Q.JX`,6JFWU
M_Y>5>@"Y\U-!J?5;0JGW8T.I_7O$J,`#7]9_`A;K8`(!D8D!`%1_`A?K(_O_
M5&`&0*VU`@%1P`8`K6`&0:WS`P"JX`,4JL`&`:UH^_^7XO__%^+^_U3?`@#K
M]/__%\+\_U1@`@*+WP(`Z^+__Q?]>[RIX@^`$OT#`)'S4P&I]`,`JO,#`:KU
M6P*I->``D?<;`/D@%$#Y-BA`N3<P0+D`(`-3U@K`6@$$`!'W"L!:HLH@.*#"
M(8L_X`!QC0D`5`((@%)"``%+`0"`4D)\0).=]/^7X`,3JD7[_Y>_&@#Y``0`
M3Z`"`*V@"H`]X`,3JG=:#BD^^_^78`)`^0#\6-.``@`Y8`)`^0#\4-.`!@`Y
M8`)`^0#\2-.`"@`Y8`)`^8`.`#E@!D#Y`/Q8TX`2`#E@!D#Y`/Q0TX`6`#E@
M!D#Y`/Q(TX`:`#E@!D#Y@!X`.6`*0/D`_%C3@"(`.6`*0/D`_%#3@"8`.6`*
M0/D`_$C3@"H`.6`*0/F`+@`Y8`Y`^0#\6-.`,@`Y8`Y`^0#\4-.`-@`Y8`Y`
M^0#\2-.`.@`Y8`Y`^8`^`#E@$D#Y`/Q8TX!"`#E@$D#Y`/Q0TX!&`#E@$D#Y
M`/Q(TX!*`#E@$D#Y@$X`.>`#$ZKS4T&I]5M"J?<;0/G]>\2HW_3_%P('@%)"
M``%+`0"`4D)\0)-2]/^7N___%_U[OZG]`P"1_7O!J,`#7]8N+@`E<R\E<P!$
M>6YA3&]A9&5R.CIB;V]T7T1Y;F%,;V%D97(`26YT97)N86QS.CI005(Z.D)/
M3U0`97AE`"]P<F]C+R5I+R5S`%!!4E]414U0`%!!4E]04D]'3D%-10`Z`"\`
M4$523#5,24(`4$523$Q)0@!015),-4]05`!015),24\`4$%27TE.251)04Q)
M6D5$`%!!4E]34$%73D5$`%!!4E]#3$5!3@!005)?1$5"54<`4$%27T-!0TA%
M`%!!4E]'3$]"04Q?1$5"54<`4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)
M4@!005)?1TQ/0D%,7U1%35``4$%27T=,3T)!3%]#3$5!3@`Q`$Q$7TQ)0E)!
M4EE?4$%42`!365-414T`)3`R>`!P87(M`"5S)7,E<R5S`"5S.B!C<F5A=&EO
M;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I
M*0H`)7,Z('!R:79A=&4@<W5B9&ER96-T;W)Y("5S(&ES('5N<V%F92`H<&QE
M87-E(')E;6]V92!I="!A;F0@<F5T<GD@>6]U<B!O<&5R871I;VXI"@!P87)L
M`"YP87(`)7,E<V-A8VAE+25S)7,`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE
M=2TE=25S`!@`<&5R;``P`%!!4CHZ4&%C:V5R.CI615)324].`#$N,#4W`%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y`"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO
M/25I*0H`+64`+2T`55-%4@!54T523D%-10!414U01$E2`%1-4``O=&UP`&5V
M86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@)#`@)'LQ*R(D0")])PII9B`P
M.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@<VAE;&P*<&%C:V%G92!?7W!A
M<E]P;#L*;7D@*"1005)?34%'24,L("1&24Q%7V]F9G-E=%]S:7IE+"`D8V%C
M:&5?;F%M95]S:7IE*3L*0D5'24X@>PHD4$%27TU!1TE#(#T@(EQN4$%2+G!M
M7&XB.PHD1DE,15]O9F9S971?<VEZ92`](#0[("`@(R!P86-K*").(BD*)&-A
M8VAE7VYA;65?<VEZ92`](#0P.PHD4$M:25!?34%'24,@/2`B4$M<,#`S7#`P
M-"(["GT*<W5B(&9I;F1?<&%R7VUA9VEC"GL*;7D@*"1F:"D@/2!`7SL*;7D@
M)&-H=6YK7W-I>F4@/2`V-"`J(#$P,C0["FUY("1B=68["FUY("1S:7IE(#T@
M+7,@)&9H.PIM>2`D<&]S(#T@*"1S:7IE+3$I("T@*"1S:7IE+3$I("4@)&-H
M=6YK7W-I>F4[("`@("`@(R!.3U1%.B`D<&]S(&ES(&$@;75L=&EP;&4@;V8@
M)&-H=6YK7W-I>F4*=VAI;&4@*"1P;W,@/CT@,"D@>PIS965K("1F:"P@)'!O
M<RP@,#L*<F5A9"`D9F@L("1B=68L("1C:'5N:U]S:7IE("L@;&5N9W1H*"10
M05)?34%'24,I.PII9B`H*&UY("1I(#T@<FEN9&5X*"1B=68L("1005)?34%'
M24,I*2`^/2`P*2!["G)E='5R;B`D<&]S("L@)&D["GT*)'!O<R`M/2`D8VAU
M;FM?<VEZ93L*?0IR971U<FX@+3$["GT*;7D@*"1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92P@)4UO9'5L94-A8VAE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%;
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")=*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*;7D@)&9I;&5N86UE(#T@)'1M<"T^9FEL96YA;64["G!R
M:6YT("1T;7`@/#PB+BXN(CL*>#TQ.R!W:&EL92!;(%PD>"`M;'0@,3`@73L@
M9&\*<FT@+7)F("<D<&%R7W1E;7`G"FEF(%L@7"$@+60@)R1P87)?=&5M<"<@
M73L@=&AE;@IB<F5A:PIF:0IS;&5E<"`Q"G@]8&5X<'(@7"1X("L@,6`*9&]N
M90IR;2`G)&9I;&5N86UE)PHN+BX*8VQO<V4@)'1M<#L*8VAM;V0@,#<P,"P@
M)&9I;&5N86UE.PIM>2`D8VUD(#T@(B1F:6QE;F%M92`^+V1E=B]N=6QL(#(^
M)C$@)B(["G-Y<W1E;2@D8VUD*3L*;W5T<RAQ<5M3<&%W;F5D(&)A8VMG<F]U
M;F0@<')O8V5S<R!T;R!P97)F;W)M(&-L96%N=7`Z("1F:6QE;F%M95TI.PI]
M"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F:6YE
M9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?96YV
M*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5S>7,@/2`H
M"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I
M+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R?&-Y9W=I
M;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/(#U^("]>
M35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N86UE*"D[
M"F]U=',H<7%;7"1P<F]G;F%M92`]("(D<')O9VYA;64B72D["E]S971?<&%R
M7W1E;7`H*3L*;W5T<RAQ<5M<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?
M5$5-4'TB72D["FUY("@D<W1A<G1?<&]S+"`D<W1A<G1?;V9?1DE,15]S96-T
M:6]N*3L*34%'24,Z('L*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"G5N;&5S<R`H;W!E;B!?1D@L("<\.G)A=R<L("1P<F]G;F%M92D@>PIO=71S
M*'%Q6T-A;B=T(')E860@9G)O;2!F:6QE("(D<')O9VYA;64B72D[("`C(&1O
M;B=T('5S92`D(2!H97)E(&%S(&ET(')E<75I<F5S($5R<FYO+G!M"FQA<W0@
M34%'24,["GT*;7D@)&UA9VEC7W!O<R`](&9I;F1?<&%R7VUA9VEC*"I?1D@I
M.PII9B`H)&UA9VEC7W!O<R`\(#`I('L*;W5T<RAQ<5M#86XG="!F:6YD(&UA
M9VEC('-T<FEN9R`B)%!!4E]-04=)0R(@:6X@9FEL92`B)'!R;V=N86UE(ETI
M.PIL87-T($U!1TE#.PI]"F]U=',H(D9O=6YD(%!!4B!M86=I8R!A="!P;W-I
M=&EO;B`D;6%G:6-?<&]S(BD["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)
M3$5?;V9F<V5T7W-I>F4@+2!L96YG=&@H(EPP0T%#2$4B*2P@,#L*<F5A9"!?
M1D@L("1B=68L(&QE;F=T:"@B7#!#04-(12(I.PII9B`H)&)U9B!N92`B7#!#
M04-(12(@)B8@)&)U9B!N92`B7#!#3$5!3B(I('L*;W5T<R@B3F\@8V%C:&4@
M;6%R:V5R(&9O=6YD(BD["FQA<W0@34%'24,["GT*;W5T<RAQ<5M#86-H92!M
M87)K97(@(B1B=68B(&9O=6YD72D["G-E96L@7T9(+"`D;6%G:6-?<&]S("T@
M)$9)3$5?;V9F<V5T7W-I>F4L(#`["G)E860@7T9(+"`D8G5F+"`D1DE,15]O
M9F9S971?<VEZ93L*;7D@)&]F9G-E="`]('5N<&%C:R@B3B(L("1B=68I.PIO
M=71S*")/9F9S970@9G)O;2!S=&%R="!O9B!&24Q%<R!I<R`D;V9F<V5T(BD[
M"G-E96L@7T9(+"`D;6%G:6-?<&]S("T@)$9)3$5?;V9F<V5T7W-I>F4@+2`D
M;V9F<V5T+"`P.PHD<W1A<G1?;V9?1DE,15]S96-T:6]N(#T@=&5L;"!?1D@[
M"FUY("5R97%U:7)E7VQI<W0["G)E860@7T9(+"`D8G5F+"`T.R`@("`@("`@
M("`@("`@("`@("`@("`@("`@(",@<F5A9"!T:&4@9FER<W0@(D9)3$4B"G=H
M:6QE("@D8G5F(&5Q(")&24Q%(BD@>PIR96%D(%]&2"P@)&)U9BP@-#L*<F5A
M9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PIM>2`D9G5L;&YA;64@
M/2`D8G5F.PIO=71S*'%Q6U5N<&%C:VEN9R!&24Q%("(D9G5L;&YA;64B+BXN
M72D["FUY("1C<F,@/2`H("1F=6QL;F%M92`]?B!S?%XH6V$M9EQD77LX?2DO
M?'P@*2`_("0Q(#H@=6YD968["FUY("@D8F%S96YA;64L("1E>'0I(#T@*"1B
M=68@/7X@;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*<F5A9"!?1D@L("1B=68L
M(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*:68@*&1E
M9FEN960H)&5X="D@86YD("1E>'0@(7X@+UPN*#\Z<&U\<&Q\:7A\86PI)"]I
M*2!["FUY("1F:6QE;F%M92`](%]S879E7V%S*"(D8W)C)&5X="(L("1B=68L
M(#`W-34I.PHD4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D
M9FEL96YA;64["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]
M("1F=6QL;F%M93L*?0IE;'-I9B`H("1F=6QL;F%M92`]?B!M?%XO/W-H;&EB
M+WP@86YD(&1E9FEN960@)$5.5GM005)?5$5-4'T@*2!["FUY("1F:6QE;F%M
M92`](%]S879E7V%S*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U-2D["F]U
M=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD36]D=6QE0V%C
M:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN
M86UE(#T^("1F=6QL;F%M92P*?3L*)')E<75I<F5?;&ES='LD9G5L;&YA;65]
M*RL["GT*<F5A9"!?1D@L("1B=68L(#0["GT*;&]C86P@0$E.0R`]("AS=6(@
M>PIM>2`H)'-E;&8L("1M;V1U;&4I(#T@0%\["G)E='5R;B!I9B!R968@)&UO
M9'5L92!O<B`A)&UO9'5L93L*;7D@)&EN9F\@/2`D36]D=6QE0V%C:&5[)&UO
M9'5L97T["G)E='5R;B!U;FQE<W,@)&EN9F\["F1E;&5T92`D<F5Q=6ER95]L
M:7-T>R1M;V1U;&5].PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&EN9F\O
M)&UO9'5L92(["FEF("@D14Y6>U!!4E]#3$5!3GT@86YD(&1E9FEN960H)DE/
M.CI&:6QE.CIN97<I*2!["FUY("1F:"`]($E/.CI&:6QE+3YN97=?=&UP9FEL
M92!O<B!D:64@(D-A;B=T(&-R96%T92!T96UP(&9I;&4Z("0A(CL*)&9H+3YB
M:6YM;V1E*"D["B1F:"T^<')I;G0H)&EN9F\M/GMB=69]*3L*)&9H+3YS965K
M*#`L(#`I.PIR971U<FX@)&9H.PI]"F5L<V4@>PIM>2`D9FEL96YA;64@/2!?
M<V%V95]A<R@B)&EN9F\M/GMC<F-]+G!M(BP@)&EN9F\M/GMB=69]*3L*)&EN
M9F\M/GMF:6QE?2`]("1F:6QE;F%M93L*;W!E;B!M>2`D9F@L("<\.G)A=R<L
M("1F:6QE;F%M92!O<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&5N86UE(CH@
M)"%=.PIR971U<FX@)&9H.PI]"F1I92`B0F]O='-T<F%P<&EN9R!F86EL960Z
M(&-A;B=T(&9I;F0@;6]D=6QE("1M;V1U;&4A(CL*?2P@0$E.0RD["G)E<75I
M<F4@6%-,;V%D97(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER92!#87)P
M.CI(96%V>3L*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["E!!4CHZ2&5A=GDZ
M.E]I;FET7V1Y;F%L;V%D97(H*3L*<F5Q=6ER92!)3SHZ1FEL93L*=VAI;&4@
M*&UY("1F:6QE;F%M92`]("AS;W)T(&ME>7,@)7)E<75I<F5?;&ES="E;,%TI
M('L*=6YL97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"
M4T1004XO*2!["FEF("@D9FEL96YA;64@/7X@+UPN<&UC/R0O:2D@>PIR97%U
M:7)E("1F:6QE;F%M93L*?0IE;'-E('L*9&\@)&9I;&5N86UE('5N;&5S<R`D
M9FEL96YA;64@/7X@+W-I=&5C=7-T;VUI>F5<+G!L)"\["GT*?0ID96QE=&4@
M)')E<75I<F5?;&ES='LD9FEL96YA;65].PI]"FEF("@D8G5F(&YE("102UI)
M4%]-04=)0RD@>PIO=71S*'%Q6TYO('II<"!F;W5N9"!A9G1E<B!&24Q%('-E
M8W1I;VX@:6X@9FEL92`B)'!R;V=N86UE(ETI.PIL87-T($U!1TE#(#L*?0HD
M<W1A<G1?<&]S(#T@*'1E;&P@7T9(*2`M(#0[("`@("`@("`@("`@("`@(",@
M<W1A<G0@;V8@>FEP"GT*;7D@0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L
M92P@)&QO9V9H+"`D8V%C:&5?;F%M92D["F1E;&5T92`D14Y6>U!!4E]!4%!?
M4D554T5].R`C('-A;FET:7IE("A2155312!M87D@8F4@82!S96-U<FET>2!P
M<F]B;&5M*0II9B`H(21S=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A
M<BUO<'1I;VYS)R`F)B!S:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@
M("!B;&EB7W1O7W!A<@II("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P
M87(*<R`@('-I9VY?<&%R"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A
M;F0@)$%21U9;,%T@97$@)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6
M>U!!4E]!4%!?4D554T5](#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R
M;6%L('!A<FP@8F5H879I;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%2
M1U8I('L*)$%21U9;,%T@/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@
M;W(@;&%S=#L*:68@*"0Q(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D
M,CL*?0IE;'-I9B`H)#$@97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS
M:68@*"0Q(&5Q("=!)RD@>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS
M:68@*"0Q(&5Q("=/)RD@>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B
M)RD@>PHD8G5N9&QE(#T@)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*
M)&)U;F1L92`]("=A;&PG.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T
M(#T@,3L*?0IE;'-I9B`H)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB
M+"`D,B!O<B!D:64@<7%;0V%N)W0@;W!E;B!L;V<@9FEL92`B)#(B.B`D(5T[
M"GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H
M:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D9&ES=%]C;61[)#%]*2!["F1E
M;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET7VEN8R@I.PIR97%U:7)E(%!!
M4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8[
M"B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["F5X:70["GT*
M?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC.PI]"GT*:68@*"1O=70I('L*
M>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q
M=6ER92!$:6=E<W0Z.E-(03L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM
M>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["F]P96X@;7D@)&9H+"`G/#IR
M87<G+"`D<&%R(&]R(&1I92!Q<5M#86XG="!F:6YD('!A<B!F:6QE("(D<&%R
M(CH@)"%=.PIB;&5S<R@D9F@L("=)3SHZ1FEL92<I.PHD>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B@@)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@
M)'!A<BD@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I("D*;W(@9&EE('%Q6T5R
M<F]R(')E861I;F<@>FEP(&%R8VAI=F4@(B1P87(B73L*?0IM>2`E;65T85]P
M87(@/2!D;R!["FEF("@D>FEP(&%N9"!M>2`D;65T82`]("1Z:7`M/F-O;G1E
M;G1S*"=-151!+GEM;"<I*2!["B1M971A(#U^(',O+BI><&%R.B0O+VUS.PHD
M;65T82`]?B!S+UY<4RXJ+R]M<SL*)&UE=&$@/7X@+UX@("A;7CI=*RDZ("@N
M*RDD+VUG.PI]"GT["FEF("AD969I;F5D("1P87(I('L*;W!E;B!M>2`D<&@L
M("<\.G)A=R<L("1P87(@;W(@9&EE('%Q6T-A;B=T(')E860@<&%R(&9I;&4@
M(B1P87(B.B`D(5T["FUY("1B=68["G)E860@)'!H+"`D8G5F+"`T.PID:64@
M<7%;(B1P87(B(&ES(&YO="!A('!A<B!F:6QE72!U;FQE<W,@)&)U9B!E<2`D
M4$M:25!?34%'24,["F-L;W-E("1P:#L*?0I#<F5A=&50871H*"1O=70I(#L*
M;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%
M050H*2!\($E/.CI&:6QE.CI/7U)$5U(H*2!\($E/.CI&:6QE.CI/7U1254Y#
M*"DL"C`W-S<L"BD@;W(@9&EE('%Q6T-A;B=T(&-R96%T92!F:6QE("(D;W5T
M(CH@)"%=.PHD9F@M/F)I;FUO9&4H*3L*<V5E:R!?1D@L(#`L(#`["FUY("1L
M;V%D97(["FEF("AD969I;F5D("1S=&%R=%]O9E]&24Q%7W-E8W1I;VXI('L*
M<F5A9"!?1D@L("1L;V%D97(L("1S=&%R=%]O9E]&24Q%7W-E8W1I;VX["GT@
M96QS92!["FQO8V%L("0O(#T@=6YD968["B1L;V%D97(@/2`\7T9(/CL*?0II
M9B`H(21%3E9[4$%27U9%4D)!5$E-?2!A;F0@)&QO861E<B`]?B`O7B@_.B,A
M?%Q`<F5M*2\I('L*<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["E!!
M4CHZ1FEL=&5R.CI0;V13=')I<"T^87!P;'DH7"1L;V%D97(L("0P*3L*?0HD
M9F@M/G!R:6YT*"1L;V%D97(I"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG(&QO
M861E<B!T;R`B)&]U="(Z("0A73L*:68@*"1B=6YD;&4I('L*<F5Q=6ER92!0
M05(Z.DAE879Y.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["FEN
M:71?:6YC*"D["G)E<75I<F5?;6]D=6QE<R@I.PIM>2!`:6YC(#T@9W)E<"![
M("$O0E-$4$%.+R!]"F=R97`@>PHH)&)U;F1L92!N92`G<VET92<I(&]R"B@D
M7R!N92`D0V]N9FEG.CI#;VYF:6=[87)C:&QI8F5X<'T@86YD"B1?(&YE("1#
M;VYF:6<Z.D-O;F9I9WMP<FEV;&EB97AP?2D["GT@0$E.0SL*<WPO*WPO?&<L
M('-\+R1\?"!F;W)E86-H($!I;F,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK
M(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E
M24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L@
M("`@("`@("`C(%A86"!L:6)?97AT('9S(&1L97AT(#\*;7D@)7=R:71T96X[
M"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5F:6QE<RD@>PIM>2`H)&9I
M;&4L("1N86UE*3L*:68@*&1E9FEN960H;7D@)&9C(#T@)%!!4CHZ2&5A=GDZ
M.D9U;&Q#86-H97LD:V5Y?2DI('L**"1F:6QE+"`D;F%M92D@/2`H)&ME>2P@
M)&9C*3L*?0IE;'-E('L*9F]R96%C:"!M>2`D9&ER("A`:6YC*2!["FEF("@D
M:V5Y(#U^(&U\7EQ1)&1I<EQ%+R@N*BDD?&DI('L**"1F:6QE+"`D;F%M92D@
M/2`H)&ME>2P@)#$I.PIL87-T.PI]"FEF("@D:V5Y(#U^(&U\7B]L;V%D97(O
M6UXO72LO*"XJ*21\*2!["FEF("AM>2`D<F5F(#T@)$UO9'5L94-A8VAE>R0Q
M?2D@>PHH)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D["FQA<W0["GT*:68@
M*"UF("(D9&ER+R0Q(BD@>PHH)&9I;&4L("1N86UE*2`]("@B)&1I<B\D,2(L
M("0Q*3L*;&%S=#L*?0I]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE
M.PIN97AT(&EF("1W<FET=&5N>R1N86UE?2LK.PIN97AT(&EF("%R968H)&9I
M;&4I(&%N9"`D9FEL92`]?B`O7"Y<421L:6)?97AT7$4D+VD["F]U=',H<W!R
M:6YT9BAQ<5M086-K:6YG($9)3$4@(B5S(BXN+ETL(')E9B`D9FEL92`_("1F
M:6QE+3Y[;F%M97T@.B`D9FEL92DI.PIM>2`D8V]N=&5N=#L*:68@*')E9B@D
M9FEL92DI('L*)&-O;G1E;G0@/2`D9FEL92T^>V)U9GT["GT*96QS92!["FQO
M8V%L("0O(#T@=6YD968["F]P96X@;7D@)'1H+"`G/#IR87<G+"`D9FEL92!O
M<B!D:64@<7%;0V%N)W0@<F5A9"`B)&9I;&4B.B`D(5T["B1C;VYT96YT(#T@
M/"1T:#X["F-L;W-E("1T:#L*4$%2.CI&:6QT97(Z.E!O9%-T<FEP+3YA<'!L
M>2A<)&-O;G1E;G0L("(\96UB961D960^+R1N86UE(BD*:68@(21%3E9[4$%2
M7U9%4D)!5$E-?2!A;F0@)&YA;64@/7X@+UPN*#\Z<&U\:7A\86PI)"]I.PI0
M05(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P<&QY*%PD8V]N=&5N
M="P@)&9I;&4L("1N86UE*3L*?0HD9F@M/G!R:6YT*")&24Q%(BP*<&%C:R@G
M3B<L(&QE;F=T:"@D;F%M92D@*R`Y*2P*<W!R:6YT9B@B)3`X>"\E<R(L($%R
M8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@)&YA;64I+`IP
M86-K*"=.)RP@;&5N9W1H*"1C;VYT96YT*2DL"B1C;VYT96YT*0IO<B!D:64@
M<7%;17)R;W(@=W)I=&EN9R!E;6)E9&1E9"!&24Q%('1O("(D;W5T(CH@)"%=
M.PIO=71S*'%Q6U=R:71T96X@87,@(B1N86UE(ETI.PI]"GT*:68@*"1Z:7`I
M('L*)'II<"T^=W)I=&54;T9I;&5(86YD;&4H)&9H*2`]/2!!<F-H:79E.CI:
M:7`Z.D%:7T]+"F]R(&1I92!Q<5M%<G)O<B!W<FET:6YG('II<"!P87)T(&]F
M("(D;W5T(ET["GT*:68@*"1M971A7W!A<GMC;&5A;GTI('L*)&9H+3YP<FEN
M="@B7#!#3$5!3B(I.PI]"F5L<V4@>PII9B`H(61E9FEN960@)&-A8VAE7VYA
M;64I('L*;7D@)&-T>"`]($1I9V5S=#HZ4TA!+3YN97<H,2D["G-E96L@)&9H
M+"`P+"`P.PHD8W1X+3YA9&1F:6QE*"1F:"D["G-E96L@)&9H+"`P+"`R.PHD
M8V%C:&5?;F%M92`]("1C='@M/FAE>&1I9V5S=#L*?0HD8V%C:&5?;F%M92`]
M('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@)&-A8VAE7VYA;65?<VEZ93L*)&-A
M8VAE7VYA;64@+CT@(EPP(B!X("@D8V%C:&5?;F%M95]S:7IE("T@;&5N9W1H
M("1C86-H95]N86UE*3L*)&9H+3YP<FEN="@D8V%C:&5?;F%M92P*(EPP0T%#
M2$4B*3L*?0IM>2`D;V9F<V5T(#T@)&9H+3YT96QL("T@;&5N9W1H*"1L;V%D
M97(I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D;V9F<V5T*2P*)%!!4E]-04=)
M0RD["B1F:"T^8VQO<V4@;W(@9&EE('%Q6T5R<F]R('=R:71I;F<@=')A:6QE
M<B!O9B`B)&]U="(Z("0A73L*8VAM;V0@,#<U-2P@)&]U=#L*97AI=#L*?0I[
M"FQA<W0@=6YL97-S(&1E9FEN960@)'-T87)T7W!O<SL*7V9I>%]P<F]G;F%M
M92@I.PIR97%U:7)E(%!!4CL*4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E
M<B@I.PI["G)E<75I<F4@1FEL93HZ1FEN9#L*<F5Q=6ER92!!<F-H:79E.CI:
M:7`["GT*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=SL@("`@("`@("`@("`@("`@
M("`@("`@("`@("`@(",@07)C:&EV93HZ6FEP(&]P97)A=&5S(&]N(&%N($E/
M.CI(86YD;&4*)&9H+3YF9&]P96XH9FEL96YO*%]&2"DL("=R)RD@;W(@9&EE
M('%Q6V9D;W!E;B@I(&9A:6QE9#H@)"%=.PI!<F-H:79E.CI::7`Z.G-E=$-H
M=6YK4VEZ92@M<R!?1D@I.PIM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<[
M"B@D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]
M($%R8VAI=F4Z.EII<#HZ05I?3TLH*2D*;W(@9&EE('%Q6T5R<F]R(')E861I
M;F<@>FEP(&%R8VAI=F4@(B1P<F]G;F%M92)=.PI!<F-H:79E.CI::7`Z.G-E
M=$-H=6YK4VEZ92@V-"`J(#$P,C0I.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D
M>FEP.PHD4$%2.CI,:6)#86-H97LD<')O9VYA;65](#T@)'II<#L*;W5T<R@B
M17AT<F%C=&EN9R!Z:7`N+BXB*3L*:68@*&1E9FEN960@)$5.5GM005)?5$5-
M4'TI('L@(R!S:&]U;&0@8F4@<V5T(&%T('1H:7,@<&]I;G0A"F9O<F5A8V@@
M;7D@)&UE;6)E<B`H("1Z:7`M/FUE;6)E<G,@*2!["FYE>'0@:68@)&UE;6)E
M<BT^:7-$:7)E8W1O<GD["FUY("1M96UB97)?;F%M92`]("1M96UB97(M/F9I
M;&5.86UE.PIN97AT('5N;&5S<R`D;65M8F5R7VYA;64@/7X@;7L*7@HO/W-H
M;&EB+PHH/SHD0V]N9FEG.CI#;VYF:6=[=F5R<VEO;GTO*3\**#\Z)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAN86UE?2\I/PHH6UXO72LI"B0*?7@["FUY("1E>'1R
M86-T7VYA;64@/2`D,3L*;7D@)&1E<W1?;F%M92`]($9I;&4Z.E-P96,M/F-A
M=&9I;&4H)$5.5GM005)?5$5-4'TL("1E>'1R86-T7VYA;64I.PII9B`H+68@
M)&1E<W1?;F%M92`F)B`M<R!?(#T]("1M96UB97(M/G5N8V]M<')E<W-E9%-I
M>F4H*2D@>PIO=71S*'%Q6U-K:7!P:6YG("(D;65M8F5R7VYA;64B('-I;F-E
M(&ET(&%L<F5A9'D@97AI<W1S(&%T("(D9&5S=%]N86UE(ETI.PI](&5L<V4@
M>PIO=71S*'%Q6T5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T
M7VYA;64B+BXN72D["B@D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M960H)&1E
M<W1?;F%M92D@/3T@07)C:&EV93HZ6FEP.CI!6E]/2R@I*0IO<B!D:64@<7%;
M17)R;W(@97AT<F%C=&EN9R!Z:7`@;65M8F5R('1O("(D9&5S=%]N86UE(ET[
M"F-H;6]D*#`U-34L("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*
M?0I]"GT*=6YL97-S("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I
M92`\/"`B+B(@=6YL97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@
M72!;("U)9&ER(%T@6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A
M;2YP;"!="B0P(%L@+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.
M5GM005)?4%)/1TY!345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'
M5BD["GT*<W5B($-R96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I
M<F4@1FEL93HZ0F%S96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT
M*2`]($9I;&4Z.D)A<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I
M*3L*<F5Q=6ER92!&:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A
M=&@I('5N;&5S<R@M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O
M<@I]"G-U8B!R97%U:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER
M92!$>6YA3&]A9&5R.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T
M.PIR97%U:7)E('=A<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R
M<#L*<F5Q=6ER92!#87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER
M92!%>'!O<G1E<CHZ2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@
M1F-N=&P["G)E<75I<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)
M3SHZ2&%N9&QE.PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S
M.CI:;&EB.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!$:6=E<W0Z
M.E-(03L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*<F5Q=6ER
M92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PIR
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I<F4@871T
M<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R97%U:7)E
M(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!].PIE=F%L
M('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A;"![(')E
M<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![(')E<75I
M<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V86P@>R!R
M97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF("AD969I
M;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK
M*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H(&UY("1P
M871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%
M35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@*0HI('L*
M;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@86YD("UW
M("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![*"1P=W5I
M9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H(&1E9FEN
M960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F5VEN,S(Z
M.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*)'5S97)N
M86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6>U5315).
M04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"FUY("1S=&UP9&ER
M(#T@(B1P871H)'-Y<WM?9&5L:6U]<&%R+2(N=6YP86-K*")(*B(L("1U<V5R
M;F%M92D["FUK9&ER("1S=&UP9&ER+"`P-S4U.PIM>2`D8V%C:&5?9&ER.PII
M9B`H)$5.5GM005)?0TQ%04Y]*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"([
M"GT*96QS92!["F]P96X@;7D@)&9H+"`B/#IR87<B+"`D<')O9VYA;64@;W(@
M9&EE('%Q6T-A;B=T(')E860@(B1P<F]G;F%M92(Z("0A73L*:68@*"AM>2`D
M;6%G:6-?<&]S(#T@9FEN9%]P87)?;6%G:6,H)&9H*2D@/CT@,"D@>PIS965K
M("1F:"P@)&UA9VEC7W!O<PHM("1&24Q%7V]F9G-E=%]S:7IE"BT@;&5N9W1H
M*")<,$-!0TA%(BDL(#`["FUY("1B=68["G)E860@)&9H+"`D8G5F+"!L96YG
M=&@H(EPP0T%#2$4B*3L*:68@*"1B=68@97$@(EPP0T%#2$4B*2!["G-E96L@
M)&9H+"`D;6%G:6-?<&]S"BT@)$9)3$5?;V9F<V5T7W-I>F4*+2!L96YG=&@H
M(EPP0T%#2$4B*0HM("1C86-H95]N86UE7W-I>F4L(#`["G)E860@)&9H+"`D
M8G5F+"`D8V%C:&5?;F%M95]S:7IE.PHD8G5F(#U^(',O7#`O+V<["B1C86-H
M95]D:7(@/2`B8V%C:&4M)&)U9B(["GT*?0IC;&]S92`D9F@["GT*:68@*"$D
M8V%C:&5?9&ER*2!["B1C86-H95]D:7(@/2`B=&5M<"TD)"(["B1%3E9[4$%2
M7T-,14%.?2`](#$["GT*)'-T;7!D:7(@+CT@(B1S>7-[7V1E;&EM?21C86-H
M95]D:7(B.PIM:V1I<B`D<W1M<&1I<BP@,#<U-3L*)$5.5GM005)?5$5-4'T@
M/2`D<W1M<&1I<CL*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M<V%V95]A<R!["FUY("@D;F%M92P@)&-O;G1E;G1S+"`D;6]D92D@/2!`7SL*
M;7D@)&9U;&QN86UE(#T@(B1P87)?=&5M<"\D;F%M92(["G5N;&5S<R`H+64@
M)&9U;&QN86UE*2!["FUY("1T96UP;F%M92`]("(D9G5L;&YA;64N)"0B.PIM
M>2`D9F@["BAO<&5N("1F:"P@)SXZ<F%W)RP@)'1E;7!N86UE*0HF)B`H<')I
M;G0@)&9H("1C;VYT96YT<RD*)B8@*&-L;W-E("1F:"D*;W(@9&EE('%Q6T5R
M<F]R('=R:71I;F<@(B1T96UP;F%M92(Z("0A73L*8VAM;V0@)&UO9&4L("1T
M96UP;F%M92!I9B!D969I;F5D("1M;V1E.PIR96YA;64H)'1E;7!N86UE+"`D
M9G5L;&YA;64I(&]R('5N;&EN:R@D=&5M<&YA;64I.PI]"G)E='5R;B`D9G5L
M;&YA;64["GT*<W5B(%]S971?<')O9VYA;64@>PII9B`H9&5F:6YE9"`D14Y6
M>U!!4E]04D]'3D%-17T@86YD("1%3E9[4$%27U!23T=.04U%?2`]?B`O*"XK
M*2\I('L*)'!R;V=N86UE(#T@)#$["GT*)'!R;V=N86UE('Q\/2`D,#L*:68@
M*"1%3E9[4$%27U1%35!](&%N9"!I;F1E>"@D<')O9VYA;64L("1%3E9[4$%2
M7U1%35!]*2`^/2`P*2!["B1P<F]G;F%M92`]('-U8G-T<B@D<')O9VYA;64L
M(')I;F1E>"@D<')O9VYA;64L("1S>7-[7V1E;&EM?2D@*R`Q*3L*?0II9B`H
M(21%3E9[4$%27U!23T=.04U%?2!O<B!I;F1E>"@D<')O9VYA;64L("1S>7-[
M7V1E;&EM?2D@/CT@,"D@>PII9B`H;W!E;B!M>2`D9F@L("<\)RP@)'!R;V=N
M86UE*2!["G)E='5R;B!I9B`M<R`D9F@["GT*:68@*"US("(D<')O9VYA;64D
M<WES>U]E>&5](BD@>PHD<')O9VYA;64@+CT@)'-Y<WM?97AE?3L*<F5T=7)N
M.PI]"GT*9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D<WES>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PIN97AT(&EF(&5X:7-T<R`D14Y6>U!!4E]4
M14U0?2!A;F0@)&1I<B!E<2`D14Y6>U!!4E]414U0?3L*)&1I<B`]?B!S+UQ1
M)'-Y<WM?9&5L:6U]7$4D+R\["B@H)'!R;V=N86UE(#T@(B1D:7(D<WES>U]D
M96QI;7TD<')O9VYA;64D<WES>U]E>&5](BDL(&QA<W0I"FEF("US("(D9&ER
M)'-Y<WM?9&5L:6U])'!R;V=N86UE)'-Y<WM?97AE?2(["B@H)'!R;V=N86UE
M(#T@(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B*2P@;&%S="D*:68@+7,@
M(B1D:7(D<WES>U]D96QI;7TD<')O9VYA;64B.PI]"GT*<W5B(%]F:7A?<')O
M9VYA;64@>PHD,"`]("1P<F]G;F%M92!\?#T@)$5.5GM005)?4%)/1TY!345]
M.PII9B`H:6YD97@H)'!R;V=N86UE+"`D<WES>U]D96QI;7TI(#P@,"D@>PHD
M<')O9VYA;64@/2`B+B1S>7-[7V1E;&EM?21P<F]G;F%M92(["GT*;7D@)'!W
M9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z.F=E=&-W9"@I"CH@
M*"AD969I;F5D("97:6XS,CHZ1V5T0W=D*2`_(%=I;C,R.CI'971#=V0H*2`Z
M(&!P=V1@*3L*8VAO;7`H)'!W9"D["B1P<F]G;F%M92`]?B!S+UXH/SU<+EPN
M/UQ1)'-Y<WM?9&5L:6U]7$4I+R1P=V0D<WES>U]D96QI;7TO.PHD14Y6>U!!
M4E]04D]'3D%-17T@/2`D<')O9VYA;64["GT*<W5B(%]P87)?:6YI=%]E;G8@
M>PII9B`H("1%3E9[4$%27TE.251)04Q)6D5$?2LK(#T](#$@*2!["G)E='5R
M;CL*?2!E;'-E('L*)$5.5GM005)?24Y)5$E!3$E:141](#T@,CL*?0IF;W(@
M*'%W*"!34$%73D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@
M*2`I('L*9&5L971E("1%3E9[(E!!4E\D7R)].PI]"F9O<B`H<7<O(%1-4$1)
M4B!414U0($-,14%.($1%0E5'("\I('L*)$5.5GLB4$%27R1?(GT@/2`D14Y6
M>R)005)?1TQ/0D%,7R1?(GT@:68@97AI<W1S("1%3E9[(E!!4E]'3$]"04Q?
M)%\B?3L*?0II9B`H)$5.5GM005)?5$5-4'TI('L*9&5L971E("1%3E9[4$%2
M7T-,14%.?3L*?0I]"G-U8B!O=71S('L*<F5T=7)N(&EF("1Q=6EE=#L*:68@
M*"1L;V=F:"D@>PIP<FEN="`D;&]G9F@@(D!?7&XB.PI]"F5L<V4@>PIP<FEN
M="`B0%]<;B(["GT*?0IS=6(@:6YI=%]I;F,@>PIR97%U:7)E($-O;F9I9SL*
M<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D0V]N9FEG.CI#;VYF:6=[
M)%]]+"!Q=R@*87)C:&QI8F5X<"!P<FEV;&EB97AP('-I=&5A<F-H97AP('-I
M=&5L:6)E>'`*=F5N9&]R87)C:&5X<"!V96YD;W)L:6)E>'`**3L*?0IP86-K
M86=E(&UA:6X["G)E<75I<F4@4$%2.PIU;G-H:69T($!)3D,L(%PF4$%2.CIF
M:6YD7W!A<CL*4$%2+3YI;7!O<G0H0'!A<E]A<F=S*3L*9&EE('%Q6W!A<BYP
M;#H@0V%N)W0@;W!E;B!P97)L('-C<FEP="`B)'!R;V=N86UE(CH@3F\@<W5C
M:"!F:6QE(&]R(&1I<F5C=&]R>5QN70IU;FQE<W,@+64@)'!R;V=N86UE.PID
M;R`D<')O9VYA;64["D-/4D4Z.F5X:70H)#$I(&EF("@D0"`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D0"!I9B`D0#L*?3L*)#HZ7U]%4E)/4B`]
M("1`(&EF("1`.PI]"D-/4D4Z.F5X:70H)#$I(&EF("@D.CI?7T524D]2(#U^
M+UY?5$M?15A)5%]<*"A<9"LI7"DO*3L*9&EE("0Z.E]?15)23U(@:68@)#HZ
M7U]%4E)/4CL*,3L*7U]%3D1?7PH`<&5R;'AS:2YC``!#04-(10`!&P,[_```
M`!X````0D___3`4```"5__\4`0``,)7__R@!``!PE?__/`$``-"5__]@`0``
M!);__X`!``#`EO__M`$```R7___4`0``H)?___P!```PF/__(`(``'R9__]4
M`@``H)K__YP"``!LG/__U`(``)B<___H`@``Z)S__PP#```<GO__/`,``"">
M__]0`P``!*#__Y0#```TH/__N`,``%"A___P`P``>*+__R`$``"PHO__0`0`
M`-"B__]@!```A*/__Y@$``"XJ/__[`0``)2J__\<!0``^*K__W@%``"\N___
MG`4``!B\__^\!0``?+W___0%````````$``````````!>E(`!'@>`1L,'P`0
M````&````.23__\P`````````!`````L`````)3__SP`````````(````$``
M```LE/__8`````!!#B"=!)X#0I,"5-[=TPX`````'````&0```!HE/__-```
M``!$#A"=`IX!1][=#@`````P````A````'R4__^\`````$$.0)T(G@=$DP:4
M!94$E@.7`I@!8PK>W=?8U=;3U`X`00L`'````+@````$E?__3`````!##B"=
M!)X#3][=#@`````D````V````#"5__^4`````$$.0)T(G@="DP:4!465!%S>
MW=73U`X`(``````!``"<E?__D`````!!#K`!G1:>%423%%[>W=,.````,```
M`"0!```(EO__3`$```!!#M`!G1J>&4:3&)07E1:6%9<4F!,"2][=U]C5UM/4
M#@```$0```!8`0``()?__R0!````00Y000[0@`1$G8I`GHE`0Y.(0)2'0)6&
M0):%0$.7A$"8@T!ZW=[7V-76T]1!#H"`!$$.`````#0```"@`0``_)?__\P!
M````00Y@G0R>"T*3"I0)1Y4(E@>7!I@%F00":-[=V=?8U=;3U`X`````$```
M`-@!``"0F?__+``````````@````[`$``*B9__]0`````$$.()T$G@-"DP*4
M`4K>W=/4#@`L````$`(``-29__\T`0```$(.T$!#G8H(GHD(0I.(")2'"$*5
MA@@"0]W>U=/4#@`0````0`(``-B:__\$`````````$````!4`@``R)K__^0!
M````0@[@(4&=G`2>FP1"DYH$E)D$1Y68!):7!)>6!)B5!)F4!)J3!`)LW=[9
MVM?8U=;3U`X`(````)@"``!HG/__,`````!!#B"=!)X#0Y,"1][=TPX`````
M-````+P"``!TG/__'`$```!"#K`@0YV&!)Z%!$*3A`24@P1T"MW>T]0.`$$+
M1PK=WM/4#@!""P`L````]`(``%B=__\H`0```$$.,)T&G@5$DP24`T.5`I8!
M>0K>W=76T]0.`$(+```<````)`,``%">__\X`````$$.$)T"G@%*"M[=#@!!
M"QP```!$`P``:)[__R``````00X0G0*>`4;>W0X`````-````&0#``!HGO__
MM`````!!#C"=!IX%0I4"E@%#DP24`TP*WMW5UM/4#@!!"UG>W=76T]0.``!0
M````G`,``.2>__\T!0```$$.@`.=,)XO0I,NE"U$E2R6*T*7*I@I0YDHFB="
MFR9H"M[=V]G:U]C5UM/4#@!!"P)7"M[=V]G:U]C5UM/4#@!!"P`L````\`,`
M`,2C___<`0```$$.0)T(G@="DP:4!465!)8#EP(";M[=U]76T]0.```L````
M(`0``'"E__]D`````$$.()T$G@-"DP*4`5(*WMW3U`X`00M"WMW3U`X````H
M````4`0``+R-__^H`0```$$.4)T*G@E"DPB4!T25!@)?"M[=U=/4#@!!"R``
M``!\!```>*7__\00````00Z@!46=5)Y3`RH$W=X.`````!P```"@!```&+;_
M_UP`````00X0G0*>`57>W0X`````-````,`$``!4MO__9`$```!!#D"=")X'
M0I,&E`5$E026`T*7`I@!>@K>W=?8U=;3U`X`00L````P````^`0``("W__^4
M`0```$$.0)T(G@=#DP:4!4.5!)8#0I<"`E4*WMW7U=;3U`X`00L`````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````"`@````````P!\````````!`````````/8"````````
M`0`````````!`P````````\`````````3P0````````,`````````'@9````
M````#0````````!@20```````!D`````````F/L!```````;``````````@`
M````````&@````````"@^P$``````!P`````````"`````````#U_O]O````
M`"`"````````!0````````#(#`````````8`````````"`,````````*````
M`````&T$````````"P`````````8`````````!4````````````````````#
M`````````(C]`0```````@````````"(!0```````!0`````````!P``````
M```7`````````/`3````````!P`````````X$0````````@`````````N`(`
M```````)`````````!@`````````&````````````````````/O__V\`````
M`0``"`````#Y__]O`````!``````````````````````````````````````
M````````````````````````````````````````````````````````````
M``````````````````````````````````````````````````"0&0``````
M`)`9````````D!D```````"0&0```````)`9````````D!D```````"0&0``
M`````)`9````````D!D```````"0&0```````)`9````````D!D```````"0
M&0```````)`9````````D!D```````"0&0```````)`9````````D!D`````
M``"0&0```````)`9````````D!D```````"0&0```````)`9````````D!D`
M``````"0&0```````)`9````````D!D```````"0&0```````)`9````````
MD!D```````"0&0```````)`9````````D!D```````"0&0```````)`9````
M````D!D```````"0&0```````)`9````````D!D```````"0&0```````)`9
M````````D!D```````"0&0```````)`9````````D!D```````"0&0``````
M`)`9````````D!D```````"0&0```````)`9````````D!D```````"0&0``
M`````)`9````````D!D```````"0&0```````)`9````````D!D```````"0
M&0```````)`9````````J/L!``````!@'0``````````````````````````
M``!@20````````````````````````````!X&0``````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````@``````"E!!4BYP;0H``````````!9,````
M````<4D``````````````````%)*````````2TH````````*3````````&A*
M````````$DP``````````````````/Q+`````````4P`````````````````
M`!M,````````1T-#.B`H06QP:6YE(#$R+C(N,5]G:70R,#(R,#DR-"UR-"D@
M,3(N,BXQ(#(P,C(P.3(T```N<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`
M+F1Y;G-Y;0`N9'EN<W1R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E
M>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N9'EN86UI8P`N9V]T`"YD871A`"YB<W,`
M+F-O;6UE;G0`````````````````````````````````````````````````
M```````````````````````````````````````````````+`````0````(`
M``````````(``````````@```````!H````````````````````!````````
M````````````$P```/;__V\"`````````"`"````````(`(```````#H````
M``````,`````````"````````````````````!T````+`````@`````````(
M`P````````@#````````P`D````````$`````P````@`````````&```````
M```E`````P````(`````````R`P```````#(#````````&T$````````````
M```````!````````````````````+0````0````"`````````#@1````````
M.!$```````"X`@````````,`````````"``````````8`````````#<````$
M````0@````````#P$P```````/`3````````B`4````````#````$0````@`
M````````&`````````!!`````0````8`````````>!D```````!X&0``````
M`!`````````````````````$````````````````````/`````$````&````
M`````)`9````````D!D```````#0`P``````````````````$```````````
M`````````$<````!````!@````````!@'0```````&`=`````````"P`````
M`````````````!````````````````````!-`````0````8`````````8$D`
M``````!@20```````!`````````````````````$````````````````````
M4P````$````"`````````'!)````````<$D```````#@0```````````````
M`````0```````````````````%L````!`````@````````!0B@```````%"*
M````````_`````````````````````0```````````````````!I`````0``
M``(`````````4(L```````!0BP```````"P%```````````````````(````
M````````````````<P````X````#`````````)C[`0``````F/L````````(
M````````````````````"``````````(`````````'\````/`````P``````
M``"@^P$``````*#[````````"`````````````````````@`````````"```
M``````"+````!@````,`````````J/L!``````"H^P```````.`!````````
M!``````````(`````````!``````````E`````$````#`````````(C]`0``
M````B/T```````!X`@``````````````````"``````````(`````````)D`
M```!`````P````````````(``````````0``````@```````````````````
M``@```````````````````"?````"`````,`````````@``"``````"```$`
M`````%@````````````````````(````````````````````I`````$````P
M````````````````````@``!```````T`````````````````````0``````
M```!``````````$````#`````````````````````````+0``0``````K0``
=``````````````````$`````````````````````
